# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionResponse.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15missionResponse.proto\x12\x05\x63olav\"\xbf\x02\n\x0fMissionResponse\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12;\n\x08response\x18\x03 \x01(\x0b\x32).colav.MissionResponse.MissionResponseMsg\x1a\xce\x01\n\x12MissionResponseMsg\x12H\n\x04type\x18\x01 \x01(\x0e\x32:.colav.MissionResponse.MissionResponseMsg.ResponseTypeEnum\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\"]\n\x10ResponseTypeEnum\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10MISSION_STARTING\x10\x01\x12\x11\n\rMISSION_ERROR\x10\x02\x12\x13\n\x0fMISSION_INVALID\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'missionResponse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MISSIONRESPONSE']._serialized_start=33
  _globals['_MISSIONRESPONSE']._serialized_end=352
  _globals['_MISSIONRESPONSE_MISSIONRESPONSEMSG']._serialized_start=146
  _globals['_MISSIONRESPONSE_MISSIONRESPONSEMSG']._serialized_end=352
  _globals['_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM']._serialized_start=259
  _globals['_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM']._serialized_end=352
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: obstaclesUpdate.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15obstaclesUpdate.proto\x12\x05\x63olav\"\xb4\t\n\x0fObstaclesUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x01(\t\x12\x41\n\x11\x64ynamic_obstacles\x18\x02 \x03(\x0b\x32&.colav.ObstaclesUpdate.DynamicObstacle\x12?\n\x10static_obstacles\x18\x03 \x03(\x0b\x32%.colav.ObstaclesUpdate.StaticObstacle\x12\x11\n\ttimestamp\x18\x04 \x01(\t\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\x38\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\x1an\n\x04Pose\x12.\n\x08position\x18\x01 \x01(\x0b\x32\x1c.colav.ObstaclesUpdate.Point\x12\x36\n\x0borientation\x18\x02 \x01(\x0b\x32!.colav.ObstaclesUpdate.Quaternion\x1aV\n\x05State\x12)\n\x04pose\x18\x01 \x01(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x01(\x02\x1aK\n\x17\x44ynamicObstacleGeometry\x12\x0b\n\x03loa\x18\x01 \x01(\x02\x12\x0c\n\x04\x62\x65\x61m\x18\x02 \x01(\x02\x12\x15\n\rsafety_radius\x18\x03 \x01(\x02\x1aj\n\x16StaticObstacleGeometry\x12\x36\n\x10polyshape_points\x18\x01 \x03(\x0b\x32\x1c.colav.ObstaclesUpdate.Point\x12\x18\n\x10inflation_radius\x18\x02 \x01(\x02\x1a\xc7\x01\n\x0f\x44ynamicObstacle\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.colav.ObstaclesUpdate.DynamicObstacleType\x12+\n\x05state\x18\x03 \x01(\x0b\x32\x1c.colav.ObstaclesUpdate.State\x12@\n\x08geometry\x18\x04 \x01(\x0b\x32..colav.ObstaclesUpdate.DynamicObstacleGeometry\x1a\xc2\x01\n\x0eStaticObstacle\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).colav.ObstaclesUpdate.StaticObstacleType\x12)\n\x04pose\x18\x03 \x01(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12?\n\x08geometry\x18\x04 \x01(\x0b\x32-.colav.ObstaclesUpdate.StaticObstacleGeometry\":\n\x13\x44ynamicObstacleType\x12\x17\n\x13\x44YNAMIC_UNSPECIFIED\x10\x00\x12\n\n\x06VESSEL\x10\x01\"E\n\x12StaticObstacleType\x12\x16\n\x12STATIC_UNSPECIFIED\x10\x00\x12\r\n\tLAND_MASS\x10\x01\x12\x08\n\x04\x42UOY\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'obstaclesUpdate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBSTACLESUPDATE']._serialized_start=33
  _globals['_OBSTACLESUPDATE']._serialized_end=1237
  _globals['_OBSTACLESUPDATE_POINT']._serialized_start=224
  _globals['_OBSTACLESUPDATE_POINT']._serialized_end=264
  _globals['_OBSTACLESUPDATE_QUATERNION']._serialized_start=266
  _globals['_OBSTACLESUPDATE_QUATERNION']._serialized_end=322
  _globals['_OBSTACLESUPDATE_POSE']._serialized_start=324
  _globals['_OBSTACLESUPDATE_POSE']._serialized_end=434
  _globals['_OBSTACLESUPDATE_STATE']._serialized_start=436
  _globals['_OBSTACLESUPDATE_STATE']._serialized_end=522
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY']._serialized_start=524
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY']._serialized_end=599
  _globals['_OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY']._serialized_start=601
  _globals['_OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY']._serialized_end=707
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLE']._serialized_start=710
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLE']._serialized_end=909
  _globals['_OBSTACLESUPDATE_STATICOBSTACLE']._serialized_start=912
  _globals['_OBSTACLESUPDATE_STATICOBSTACLE']._serialized_end=1106
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLETYPE']._serialized_start=1108
  _globals['_OBSTACLESUPDATE_DYNAMICOBSTACLETYPE']._serialized_end=1166
  _globals['_OBSTACLESUPDATE_STATICOBSTACLETYPE']._serialized_start=1168
  _globals['_OBSTACLESUPDATE_STATICOBSTACLETYPE']._serialized_end=1237
# @@protoc_insertion_point(module_scope)
